@@ -9,8 +9,8 @@
 #
 package Test::Moose::More;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.045-18-g08363f1
-$Test::Moose::More::VERSION = '0.046';
+# git description: 0.046-21-gf16defd
+$Test::Moose::More::VERSION = '0.047';
 
 # ABSTRACT: More tools for testing Moose packages
 
@@ -43,6 +43,9 @@ use Sub::Exporter::Progressive -setup => {
         has_method_from_anywhere_ok
         has_no_method_from_anywhere_ok
 
+        method_from_pkg_ok
+        method_not_from_pkg_ok
+
         requires_method_ok
         does_not_require_method_ok
 
@@ -212,6 +215,29 @@ sub _method_ok_guts {
 }
 
 
+{
+    my $_yes = sub { $tb->ok($_[0]->original_package_name eq $_[1], "$_[3] is from $_[1]")     };
+    my $_no  = sub { $tb->ok($_[0]->original_package_name ne $_[1], "$_[3] is not from $_[1]") };
+    sub method_from_pkg_ok($$$)     { _method_from_pkg_ok($_yes, @_) }
+    sub method_not_from_pkg_ok($$$) { _method_from_pkg_ok($_no,  @_) }
+}
+
+sub _method_from_pkg_ok {
+    my ($test, $thing, $method, $orig_pkg) = @_;
+
+    ### $thing
+    my $meta = find_meta($thing);
+    my $name = _thing_name($thing, $meta);
+
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+    my $mmeta = $meta->find_method_by_name($method)
+        or return $tb->ok(0, "$name has no method $method");
+
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+    return $test->($mmeta, $orig_pkg, $meta, "${name}'s method $method");
+}
+
+
 sub role_wraps_around_method_ok ($@) { unshift @_, 'around'; goto \&_role_wraps }
 sub role_wraps_before_method_ok ($@) { unshift @_, 'before'; goto \&_role_wraps }
 sub role_wraps_after_method_ok  ($@) { unshift @_, 'after';  goto \&_role_wraps }
@@ -386,6 +412,9 @@ sub _validate_subtest_wrapper {
     return $func->($thing => %args)
         unless $args{-subtest};
 
+    $args{-subtest} = _thing_name($thing)
+        if "$args{-subtest}" eq '1';
+
     # ...or with one.
     return $tb->subtest(delete $args{-subtest} => sub { $func->($thing => %args) });
 }
@@ -719,8 +748,6 @@ sub _class_attribute_options_ok {
     return;
 }
 
-1;
-
 !!42;
 
 __END__
@@ -737,7 +764,7 @@ Test::Moose::More - More tools for testing Moose packages
 
 =head1 VERSION
 
-This document describes version 0.046 of Test::Moose::More - released April 14, 2017 as part of Test-Moose-More.
+This document describes version 0.047 of Test::Moose::More - released April 24, 2017 as part of Test-Moose-More.
 
 =head1 SYNOPSIS
 
@@ -831,6 +858,16 @@ in @methods.
 Note: This B<does> include inherited methods; see
 L<Class::MOP::Class/find_method_by_name>.
 
+=head2 method_from_pkg_ok $thing, $method, $orig_pkg
+
+Given a thing (role, class, etc) and a method, test that it originally came
+from $orig_pkg.
+
+=head2 method_not_from_pkg_ok $thing, $method, $orig_pkg
+
+Given a thing (role, class, etc) and a method, test that it did not come from
+$orig_pkg.
+
 =head2 role_wraps_around_method_ok $role, @methods
 
 Queries $role's metaclass to see if $role wraps the methods named in
